@@ -114,8 +114,8 @@ setClass("TopicModel",
                   Dim             = "integer",                  
                   control         = "TopicModelcontrol",
                   k               = "integer",
-                  terms           = "vector",
-                  documents       = "vector",
+                  terms           = "ANY",
+                  documents       = "ANY",
                   beta            = "matrix",
                   gamma           = "matrix",
                   wordassignments = "ANY",
